@@ -88,13 +88,13 @@ func checkDiffRender(t *testing.T, a, b string, diffLines ...string) {
 	}
 
 	// Test without color
-	d := aJson.diff(bJson, nil, []Option{}, strictPatchStrategy).Render()
+	d := aJson.diff(bJson, nil, &options{}, strictPatchStrategy).Render()
 	if d != diff {
 		t.Errorf("%v.diff(%v) = %v. Want %v.", a, b, d, diff)
 	}
 
 	// Test with color
-	coloredDiff := aJson.diff(bJson, nil, []Option{}, strictPatchStrategy).Render(COLOR)
+	coloredDiff := aJson.diff(bJson, nil, &options{}, strictPatchStrategy).Render(COLOR)
 	strippedDiff := stripAnsiCodes(coloredDiff)
 	if strippedDiff != diff {
 		t.Errorf("%v.diff(%v) with color (stripped) = %v. Want %v.", a, b, strippedDiff, diff)
@@ -147,29 +147,6 @@ func removeColoredParts(s string) string {
 	return result.String()
 }
 
-// stripAnsiCodes removes ANSI color escape sequences from a string
-func stripAnsiCodes(s string) string {
-	var result strings.Builder
-	inEscape := false
-	runes := []rune(s)
-
-	for i := 0; i < len(runes); i++ {
-		if !inEscape && i+1 < len(runes) && runes[i] == '\033' && runes[i+1] == '[' {
-			inEscape = true
-			i++ // skip the '['
-			continue
-		}
-		if inEscape {
-			if runes[i] == 'm' {
-				inEscape = false
-			}
-			continue
-		}
-		result.WriteRune(runes[i])
-	}
-	return result.String()
-}
-
 func TestDiffRenderPatch(t *testing.T) {
 	testCases := []struct {
 		diff    string
